@@ -1,7 +1,7 @@
 /*
  * cmd_defs.c
  *
- * Copyright (C) 2012 - 2016 James Booth <boothj5@gmail.com>
+ * Copyright (C) 2012 - 2017 James Booth <boothj5@gmail.com>
  *
  * This file is part of Profanity.
  *
@@ -200,6 +200,7 @@ static struct cmd_t command_defs[] =
             "/tls certpath",
             "/tls certpath set <path>",
             "/tls certpath clear",
+            "/tls certpath default",
             "/tls show on|off")
         CMD_DESC(
             "Handle TLS certificates. ")
@@ -215,6 +216,7 @@ static struct cmd_t command_defs[] =
             { "certpath",             "Show the trusted certificate path." },
             { "certpath set <path>",  "Specify filesystem path containing trusted certificates." },
             { "certpath clear",       "Clear the trusted certificate path." },
+            { "certpath default",     "Use default system certificate path, if it can be found." },
             { "show on|off",          "Show or hide the TLS indicator in the titlebar." })
         CMD_NOEXAMPLES
     },
@@ -1510,7 +1512,7 @@ static struct cmd_t command_defs[] =
         CMD_EXAMPLES(
             "/alias add friends /who online friends",
             "/alias add /q /quit",
-            "/alias a /away \"I'm in a meeting.\"",
+            "/alias add a /away \"I'm in a meeting.\"",
             "/alias remove q",
             "/alias list")
     },
@@ -1883,7 +1885,7 @@ static struct cmd_t command_defs[] =
             { "clear",      cmd_account_clear })
         CMD_MAINFUNC(cmd_account)
         CMD_TAGS(
-            CMD_TAG_CONNECTION
+            CMD_TAG_CONNECTION,
             CMD_TAG_PRESENCE,
             CMD_TAG_CHAT,
             CMD_TAG_GROUPCHAT)
@@ -1919,7 +1921,9 @@ static struct cmd_t command_defs[] =
             "/account clear <account> port",
             "/account clear <account> otr",
             "/account clear <account> pgpkeyid",
-            "/account clear <account> startscript")
+            "/account clear <account> startscript",
+            "/account clear <account> muc",
+            "/account clear <account> resource")
         CMD_DESC(
             "Commands for creating and managing accounts. "
             "Calling with no arguments will display information for the current account.")
@@ -1942,7 +1946,7 @@ static struct cmd_t command_defs[] =
             { "set <account> resource <resource>",      "The resource to be used for this account, defaults to 'profanity'." },
             { "set <account> password <password>",      "Password for the account, note this is currently stored in plaintext if set." },
             { "set <account> eval_password <command>",  "Shell command evaluated to retrieve password for the account. Can be used to retrieve password from keyring." },
-            { "set <account> muc <service>",            "The default MUC chat service to use, defaults to 'conference.<domainpart>' where the domain part is from the account JID." },
+            { "set <account> muc <service>",            "The default MUC chat service to use, defaults to the servers disco info response." },
             { "set <account> nick <nick>",              "The default nickname to use when joining chat rooms." },
             { "set <account> otr <policy>",             "Override global OTR policy for this account, see /otr." },
             { "set <account> pgpkeyid <pgpkeyid>",      "Set the ID of the PGP key for this account, see /pgp." },
@@ -1958,7 +1962,9 @@ static struct cmd_t command_defs[] =
             { "clear <account> otr",                    "Remove the OTR policy setting for this account." },
             { "clear <account> pgpkeyid",               "Remove pgpkeyid associated with this account." },
             { "clear <account> startscript",            "Remove startscript associated with this account." },
-            { "clear <account> theme",                  "Clear the theme setting for the account, the global theme will be used." })
+            { "clear <account> theme",                  "Clear the theme setting for the account, the global theme will be used." },
+            { "clear <account> resource",               "Remove the resource setting for this account."},
+            { "clear <account> muc",                    "Remove the default MUC service setting."})
         CMD_EXAMPLES(
             "/account add me",
             "/account set me jid me@chatty",
