@@ -1,7 +1,7 @@
 /*
  * client_events.c
  *
- * Copyright (C) 2012 - 2016 James Booth <boothj5@gmail.com>
+ * Copyright (C) 2012 - 2017 James Booth <boothj5@gmail.com>
  *
  * This file is part of Profanity.
  *
@@ -64,9 +64,13 @@ cl_ev_connect_jid(const char *const jid, const char *const passwd, const char *c
 jabber_conn_status_t
 cl_ev_connect_account(ProfAccount *account)
 {
-    char *jid = account_create_full_jid(account);
-    cons_show("Connecting with account %s as %s", account->name, jid);
-    free(jid);
+    if (account->resource) {
+        cons_show("Connecting with account %s as %s/%s", account->name, account->jid, account->resource);
+    } else if (g_strcmp0(account->name, account->jid) == 0) {
+        cons_show("Connecting with account %s", account->name);
+    } else {
+        cons_show("Connecting with account %s as %s", account->name, account->jid);
+    }
 
     return session_connect_with_account(account);
 }
@@ -75,7 +79,9 @@ void
 cl_ev_disconnect(void)
 {
     const char *jid = connection_get_fulljid();
-    cons_show("%s logged out successfully.", jid);
+    Jid *jidp = jid_create(jid);
+    cons_show("%s logged out successfully.", jidp->barejid);
+    jid_destroy(jidp);
 
     ui_disconnected();
     ui_close_all_wins();
@@ -90,7 +96,7 @@ cl_ev_disconnect(void)
 }
 
 void
-cl_ev_presence_send(const resource_presence_t presence_type, const char *const msg, const int idle_secs)
+cl_ev_presence_send(const resource_presence_t presence_type, const int idle_secs)
 {
     char *signed_status = NULL;
 
@@ -98,12 +104,13 @@ cl_ev_presence_send(const resource_presence_t presence_type, const char *const m
     char *account_name = session_get_account_name();
     ProfAccount *account = accounts_get_account(account_name);
     if (account->pgp_keyid) {
+        char *msg = connection_get_presence_msg();
         signed_status = p_gpg_sign(msg, account->pgp_keyid);
     }
     account_free(account);
 #endif
 
-    presence_send(presence_type, msg, idle_secs, signed_status);
+    presence_send(presence_type, idle_secs, signed_status);
 
     free(signed_status);
 }
@@ -129,6 +136,9 @@ cl_ev_send_msg(ProfChatWin *chatwin, const char *const msg, const char *const oo
     }
 
     char *plugin_msg = plugins_pre_chat_message_send(chatwin->barejid, msg);
+    if (plugin_msg == NULL) {
+        return;
+    }
 
 // OTR suported, PGP supported
 #ifdef HAVE_LIBOTR
@@ -211,6 +221,9 @@ void
 cl_ev_send_muc_msg(ProfMucWin *mucwin, const char *const msg, const char *const oob_url)
 {
     char *plugin_msg = plugins_pre_room_message_send(mucwin->roomjid, msg);
+    if (plugin_msg == NULL) {
+        return;
+    }
 
     message_send_groupchat(mucwin->roomjid, plugin_msg, oob_url);
 
