@@ -1,7 +1,7 @@
 /*
  * client_events.h
  *
- * Copyright (C) 2012 - 2016 James Booth <boothj5@gmail.com>
+ * Copyright (C) 2012 - 2017 James Booth <boothj5@gmail.com>
  *
  * This file is part of Profanity.
  *
@@ -42,7 +42,7 @@ jabber_conn_status_t cl_ev_connect_account(ProfAccount *account);
 
 void cl_ev_disconnect(void);
 
-void cl_ev_presence_send(const resource_presence_t presence_type, const char *const msg, const int idle_secs);
+void cl_ev_presence_send(const resource_presence_t presence_type, const int idle_secs);
 
 void cl_ev_send_msg(ProfChatWin *chatwin, const char *const msg, const char *const oob_url);
 void cl_ev_send_muc_msg(ProfMucWin *mucwin, const char *const msg, const char *const oob_url);
