@@ -1,7 +1,7 @@
 /*
  * mucwin.c
  *
- * Copyright (C) 2012 - 2016 James Booth <boothj5@gmail.com>
+ * Copyright (C) 2012 - 2017 James Booth <boothj5@gmail.com>
  *
  * This file is part of Profanity.
  *
@@ -479,18 +479,23 @@ mucwin_message(ProfMucWin *mucwin, const char *const nick, const char *const mes
     ProfWin *window = (ProfWin*)mucwin;
     char *mynick = muc_nick(mucwin->roomjid);
 
+    char ch = '-';
+    if (mucwin->message_char) {
+        ch = mucwin->message_char[0];
+    }
+
     if (g_strcmp0(nick, mynick) != 0) {
         if (g_slist_length(mentions) > 0) {
-            win_print(window, '-', 0, NULL, NO_ME | NO_EOL, THEME_ROOMMENTION, nick, "");
+            win_print(window, ch, 0, NULL, NO_ME | NO_EOL, THEME_ROOMMENTION, nick, "");
             _mucwin_print_mention(window, message, mynick, mentions);
         } else if (triggers) {
-            win_print(window, '-', 0, NULL, NO_ME | NO_EOL, THEME_ROOMTRIGGER, nick, "");
+            win_print(window, ch, 0, NULL, NO_ME | NO_EOL, THEME_ROOMTRIGGER, nick, "");
             _mucwin_print_triggers(window, message, triggers);
         } else {
-            win_print(window, '-', 0, NULL, NO_ME, THEME_TEXT_THEM, nick, message);
+            win_print(window, ch, 0, NULL, NO_ME, THEME_TEXT_THEM, nick, message);
         }
     } else {
-        win_print(window, '-', 0, NULL, 0, THEME_TEXT_ME, nick, message);
+        win_print(window, ch, 0, NULL, 0, THEME_TEXT_ME, nick, message);
     }
 }
 
@@ -861,3 +866,39 @@ mucwin_get_string(ProfMucWin *mucwin)
 
     return resstr;
 }
+
+void
+mucwin_set_enctext(ProfMucWin *mucwin, const char *const enctext)
+{
+    if (mucwin->enctext) {
+        free(mucwin->enctext);
+    }
+    mucwin->enctext = strdup(enctext);
+}
+
+void
+mucwin_unset_enctext(ProfMucWin *mucwin)
+{
+    if (mucwin->enctext) {
+        free(mucwin->enctext);
+        mucwin->enctext = NULL;
+    }
+}
+
+void
+mucwin_set_message_char(ProfMucWin *mucwin, const char *const ch)
+{
+    if (mucwin->message_char) {
+        free(mucwin->message_char);
+    }
+    mucwin->message_char = strdup(ch);
+}
+
+void
+mucwin_unset_message_char(ProfMucWin *mucwin)
+{
+    if (mucwin->message_char) {
+        free(mucwin->message_char);
+        mucwin->message_char = NULL;
+    }
+}
