@@ -1,7 +1,7 @@
 /*
  * ui.h
  *
- * Copyright (C) 2012 - 2016 James Booth <boothj5@gmail.com>
+ * Copyright (C) 2012 - 2017 James Booth <boothj5@gmail.com>
  *
  * This file is part of Profanity.
  *
@@ -146,6 +146,12 @@ void chatwin_otr_trust(ProfChatWin *chatwin);
 void chatwin_otr_untrust(ProfChatWin *chatwin);
 void chatwin_otr_smp_event(ProfChatWin *chatwin, prof_otr_smp_event_t event, void *data);
 #endif
+void chatwin_set_enctext(ProfChatWin *chatwin, const char *const enctext);
+void chatwin_unset_enctext(ProfChatWin *chatwin);
+void chatwin_set_incoming_char(ProfChatWin *chatwin, const char *const ch);
+void chatwin_unset_incoming_char(ProfChatWin *chatwin);
+void chatwin_set_outgoing_char(ProfChatWin *chatwin, const char *const ch);
+void chatwin_unset_outgoing_char(ProfChatWin *chatwin);
 
 // MUC window
 void mucwin_role_change(ProfMucWin *mucwin, const char *const role, const char *const actor, const char *const reason);
@@ -193,6 +199,10 @@ void mucwin_role_list_error(ProfMucWin *mucwin, const char *const role, const ch
 void mucwin_handle_role_list(ProfMucWin *mucwin, const char *const role, GSList *nicks);
 void mucwin_kick_error(ProfMucWin *mucwin, const char *const nick, const char *const error);
 char* mucwin_get_string(ProfMucWin *mucwin);
+void mucwin_set_enctext(ProfMucWin *mucwin, const char *const enctext);
+void mucwin_unset_enctext(ProfMucWin *mucwin);
+void mucwin_set_message_char(ProfMucWin *mucwin, const char *const ch);
+void mucwin_unset_message_char(ProfMucWin *mucwin);
 
 // MUC private chat window
 void privwin_incoming_msg(ProfPrivateWin *privatewin, const char *const message, GDateTime *timestamp);
