@@ -52,6 +52,7 @@ int main(int argc, char* argv[]) {
         PROF_FUNC_TEST(presence_chat_with_message),
         PROF_FUNC_TEST(presence_set_priority),
         PROF_FUNC_TEST(presence_includes_priority),
+        PROF_FUNC_TEST(presence_keeps_status),
         PROF_FUNC_TEST(presence_received),
         PROF_FUNC_TEST(presence_missing_resource_defaults),
 
@@ -89,7 +90,6 @@ int main(int argc, char* argv[]) {
         PROF_FUNC_TEST(display_software_version_result_in_chat),
 
         PROF_FUNC_TEST(sends_room_join),
-        PROF_FUNC_TEST(sends_room_join_with_default_muc_service),
         PROF_FUNC_TEST(sends_room_join_with_nick),
         PROF_FUNC_TEST(sends_room_join_with_password),
         PROF_FUNC_TEST(sends_room_join_with_nick_and_password),
