@@ -15,4 +15,7 @@ void prof_input(char *input);
 int prof_output_exact(char *text);
 int prof_output_regex(char *text);
 
+void prof_timeout(int timeout);
+void prof_timeout_reset(void);
+
 #endif
