@@ -5,7 +5,7 @@
 #include <cmocka.h>
 #include <stdlib.h>
 
-#include "chat_session.h"
+#include "xmpp/chat_session.h"
 
 void returns_false_when_chat_session_does_not_exist(void **state)
 {
@@ -48,4 +48,4 @@ void removes_chat_session(void **state)
     ChatSession *session = chat_session_get(barejid);
 
     assert_null(session);
-}
\ No newline at end of file
+}
